@@ -1,4 +1,3 @@
-/* vim:set ft=c ts=2 sw=2 sts=2 et cindent: */
 /*
  * ***** BEGIN LICENSE BLOCK *****
  * Version: MIT
@@ -34,20 +33,19 @@
  * ***** END LICENSE BLOCK *****
  */
 
-#include <stdarg.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
 #include <ctype.h>
+#include <stdarg.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 
-#include <stdint.h>
 #include <amqp.h>
 #include <amqp_framing.h>
+#include <stdint.h>
 
 #include "utils.h"
 
-void die(const char *fmt, ...)
-{
+void die(const char *fmt, ...) {
   va_list ap;
   va_start(ap, fmt);
   vfprintf(stderr, fmt, ap);
@@ -56,58 +54,55 @@ void die(const char *fmt, ...)
   exit(1);
 }
 
-void die_on_error(int x, char const *context)
-{
+void die_on_error(int x, char const *context) {
   if (x < 0) {
     fprintf(stderr, "%s: %s\n", context, amqp_error_string2(x));
     exit(1);
   }
 }
 
-void die_on_amqp_error(amqp_rpc_reply_t x, char const *context)
-{
+void die_on_amqp_error(amqp_rpc_reply_t x, char const *context) {
   switch (x.reply_type) {
-  case AMQP_RESPONSE_NORMAL:
-    return;
+    case AMQP_RESPONSE_NORMAL:
+      return;
 
-  case AMQP_RESPONSE_NONE:
-    fprintf(stderr, "%s: missing RPC reply type!\n", context);
-    break;
+    case AMQP_RESPONSE_NONE:
+      fprintf(stderr, "%s: missing RPC reply type!\n", context);
+      break;
 
-  case AMQP_RESPONSE_LIBRARY_EXCEPTION:
-    fprintf(stderr, "%s: %s\n", context, amqp_error_string2(x.library_error));
-    break;
+    case AMQP_RESPONSE_LIBRARY_EXCEPTION:
+      fprintf(stderr, "%s: %s\n", context, amqp_error_string2(x.library_error));
+      break;
 
-  case AMQP_RESPONSE_SERVER_EXCEPTION:
-    switch (x.reply.id) {
-    case AMQP_CONNECTION_CLOSE_METHOD: {
-      amqp_connection_close_t *m = (amqp_connection_close_t *) x.reply.decoded;
-      fprintf(stderr, "%s: server connection error %uh, message: %.*s\n",
-              context,
-              m->reply_code,
-              (int) m->reply_text.len, (char *) m->reply_text.bytes);
+    case AMQP_RESPONSE_SERVER_EXCEPTION:
+      switch (x.reply.id) {
+        case AMQP_CONNECTION_CLOSE_METHOD: {
+          amqp_connection_close_t *m =
+              (amqp_connection_close_t *)x.reply.decoded;
+          fprintf(stderr, "%s: server connection error %uh, message: %.*s\n",
+                  context, m->reply_code, (int)m->reply_text.len,
+                  (char *)m->reply_text.bytes);
+          break;
+        }
+        case AMQP_CHANNEL_CLOSE_METHOD: {
+          amqp_channel_close_t *m = (amqp_channel_close_t *)x.reply.decoded;
+          fprintf(stderr, "%s: server channel error %uh, message: %.*s\n",
+                  context, m->reply_code, (int)m->reply_text.len,
+                  (char *)m->reply_text.bytes);
+          break;
+        }
+        default:
+          fprintf(stderr, "%s: unknown server error, method id 0x%08X\n",
+                  context, x.reply.id);
+          break;
+      }
       break;
-    }
-    case AMQP_CHANNEL_CLOSE_METHOD: {
-      amqp_channel_close_t *m = (amqp_channel_close_t *) x.reply.decoded;
-      fprintf(stderr, "%s: server channel error %uh, message: %.*s\n",
-              context,
-              m->reply_code,
-              (int) m->reply_text.len, (char *) m->reply_text.bytes);
-      break;
-    }
-    default:
-      fprintf(stderr, "%s: unknown server error, method id 0x%08X\n", context, x.reply.id);
-      break;
-    }
-    break;
   }
 
   exit(1);
 }
 
-static void dump_row(long count, int numinrow, int *chs)
-{
+static void dump_row(long count, int numinrow, int *chs) {
   int i;
 
   printf("%08lX:", count - numinrow);
@@ -137,11 +132,10 @@ static void dump_row(long count, int numinrow, int *chs)
   printf("\n");
 }
 
-static int rows_eq(int *a, int *b)
-{
+static int rows_eq(int *a, int *b) {
   int i;
 
-  for (i=0; i<16; i++)
+  for (i = 0; i < 16; i++)
     if (a[i] != b[i]) {
       return 0;
     }
@@ -149,9 +143,8 @@ static int rows_eq(int *a, int *b)
   return 1;
 }
 
-void amqp_dump(void const *buffer, size_t len)
-{
-  unsigned char *buf = (unsigned char *) buffer;
+void amqp_dump(void const *buffer, size_t len) {
+  unsigned char *buf = (unsigned char *)buffer;
   long count = 0;
   int numinrow = 0;
   int chs[16];
@@ -168,14 +161,15 @@ void amqp_dump(void const *buffer, size_t len)
       if (rows_eq(oldchs, chs)) {
         if (!showed_dots) {
           showed_dots = 1;
-          printf("          .. .. .. .. .. .. .. .. : .. .. .. .. .. .. .. ..\n");
+          printf(
+              "          .. .. .. .. .. .. .. .. : .. .. .. .. .. .. .. ..\n");
         }
       } else {
         showed_dots = 0;
         dump_row(count, numinrow, chs);
       }
 
-      for (j=0; j<16; j++) {
+      for (j = 0; j < 16; j++) {
         oldchs[j] = chs[j];
       }
 
